pub trait AllowsNoPrimaryKey: Driver { }Expand description
Marker for drivers that allow tables without a primary key.
Implement for custom drivers when the capability is available.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".